@@ -31,6 +31,12 @@
 #'   and column headings.
 #' @field calculationFilters The data filters applied to this cell from the
 #'   calculation definition.
+#' @field workingData The data filters and batchNames used applied when running
+#'   calculations (including the filters needed for base calculations when
+#'   calculation type="calculation").
+#' @field evaluationFilters The final and actual data filters used in the
+#'   calculation of the cell value (e.g. custom calculation functions can
+#'   override the working filters).
 #' @field isTotal Whether this cell is a total cell.
 #' @field rawValue The numerical calculation result.
 #' @field formattedValue The formatted calculation result (i.e. character data type).
@@ -58,31 +64,34 @@ PivotCell <- R6::R6Class("PivotCell",
                          calculationName=NULL, calculationGroupName=NULL,
                          rowFilters=NULL, columnFilters=NULL, rowColFilters=NULL,
                          rowLeafGroup=NULL, columnLeafGroup=NULL) {
-     checkArgument("PivotCell", "initialize", parentPivot, missing(parentPivot), allowMissing=FALSE, allowNull=FALSE, allowedClasses="PivotTable")
-     checkArgument("PivotCell", "initialize", rowNumber, missing(rowNumber), allowMissing=FALSE, allowNull=FALSE, allowedClasses=c("integer", "numeric"))
-     checkArgument("PivotCell", "initialize", columnNumber, missing(columnNumber), allowMissing=FALSE, allowNull=FALSE, allowedClasses=c("integer", "numeric"))
-     checkArgument("PivotCell", "initialize", calculationName, missing(calculationName), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
-     checkArgument("PivotCell", "initialize", calculationGroupName, missing(calculationGroupName), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
-     checkArgument("PivotCell", "initialize", rowFilters, missing(rowFilters), allowMissing=TRUE, allowNull=TRUE, allowedClasses="PivotFilters")
-     checkArgument("PivotCell", "initialize", columnFilters, missing(columnFilters), allowMissing=TRUE, allowNull=TRUE, allowedClasses="PivotFilters")
-     checkArgument("PivotCell", "initialize", rowColFilters, missing(rowColFilters), allowMissing=TRUE, allowNull=TRUE, allowedClasses="PivotFilters")
-     checkArgument("PivotCell", "initialize", rowLeafGroup, missing(rowLeafGroup), allowMissing=FALSE, allowNull=FALSE, allowedClasses="PivotDataGroup")
-     checkArgument("PivotCell", "initialize", columnLeafGroup, missing(columnLeafGroup), allowMissing=FALSE, allowNull=FALSE, allowedClasses="PivotDataGroup")
+     if(parentPivot$argumentCheckMode > 0) {
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", parentPivot, missing(parentPivot), allowMissing=FALSE, allowNull=FALSE, allowedClasses="PivotTable")
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", rowNumber, missing(rowNumber), allowMissing=FALSE, allowNull=FALSE, allowedClasses=c("integer", "numeric"))
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", columnNumber, missing(columnNumber), allowMissing=FALSE, allowNull=FALSE, allowedClasses=c("integer", "numeric"))
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", calculationName, missing(calculationName), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", calculationGroupName, missing(calculationGroupName), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", rowFilters, missing(rowFilters), allowMissing=TRUE, allowNull=TRUE, allowedClasses="PivotFilters")
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", columnFilters, missing(columnFilters), allowMissing=TRUE, allowNull=TRUE, allowedClasses="PivotFilters")
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", rowColFilters, missing(rowColFilters), allowMissing=TRUE, allowNull=TRUE, allowedClasses="PivotFilters")
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", rowLeafGroup, missing(rowLeafGroup), allowMissing=FALSE, allowNull=FALSE, allowedClasses="PivotDataGroup")
+       checkArgument(parentPivot$argumentCheckMode, FALSE, "PivotCell", "initialize", columnLeafGroup, missing(columnLeafGroup), allowMissing=FALSE, allowNull=FALSE, allowedClasses="PivotDataGroup")
+     }
      private$p_parentPivot <- parentPivot
-     private$p_parentPivot$message("PivotCell$new", "Creating new PivotCell",
+     if(private$p_parentPivot$traceEnabled==TRUE) private$p_parentPivot$trace("PivotCell$new", "Creating new PivotCell",
                                    list(rowNumber=rowNumber, columnNumber=columnNumber))
-     private$p_parentPivot = parentPivot
-     private$p_rowNumber = rowNumber
-     private$p_columnNumber = columnNumber
-     private$p_calculationName = calculationName
-     private$p_calculationGroupName = calculationGroupName
-     private$p_rowFilters = rowFilters
-     private$p_columnFilters = columnFilters
-     private$p_rowColFilters = rowColFilters
-     private$p_calculationFilters = NULL
-     private$p_rowLeafGroup = rowLeafGroup
-     private$p_columnLeafGroup = columnLeafGroup
-     private$p_parentPivot$message("PivotCell$new", "Created new PivotCell")
+     private$p_rowNumber <- rowNumber
+     private$p_columnNumber <- columnNumber
+     private$p_calculationName <- calculationName
+     private$p_calculationGroupName <- calculationGroupName
+     private$p_rowFilters <- rowFilters
+     private$p_columnFilters <- columnFilters
+     private$p_rowColFilters <- rowColFilters
+     private$p_calculationFilters <- NULL
+     private$p_workingData <- NULL
+     private$p_evaluationFilters <- NULL
+     private$p_rowLeafGroup <- rowLeafGroup
+     private$p_columnLeafGroup <- columnLeafGroup
+     if(private$p_parentPivot$traceEnabled==TRUE) private$p_parentPivot$trace("PivotCell$new", "Created new PivotCell")
    },
    getCopy = function() {
      copy <- list()
@@ -92,9 +101,27 @@ PivotCell <- R6::R6Class("PivotCell",
      fstr1 <- NULL
      fstr2 <- NULL
      fstr3 <- NULL
+     fstr4 <- NULL
+     fstr5 <- NULL
      if(!is.null(private$p_rowColFilters)) fstr1 <- private$p_rowColFilters$asString()
      if(!is.null(private$p_rowFilters)) fstr2 <- private$p_rowFilters$asString()
      if(!is.null(private$p_columnFilters)) fstr3 <- private$p_columnFilters$asString()
+     if(!is.null(private$p_calculationFilters)) fstr4 <- private$p_calculationFilters$asString()
+     if(!is.null(private$p_evaluationFilters)) fstr5 <- private$p_evaluationFilters$asString()
+     wdlst <- NULL
+     if(!is.null(private$p_workingData)) {
+       wdlst <- list()
+       if(length(private$p_workingData)>0) {
+         for(i in 1:length(private$p_workingData)) {
+           clst <- list()
+           fstrW <- NULL
+           if(!is.null(private$p_workingData[[i]]$workingFilters)) fstrW <- private$p_workingData[[i]]$workingFilters$asString()
+           clst$workingFilters <- fstrW
+           clst$batchName <- private$p_workingData[[i]]$batchName
+           wdlst[[names(private$p_workingData)[i]]] <- clst
+         }
+       }
+     }
      lst <- list(
        row=private$p_rowNumber,
        column=private$p_columnNumber,
@@ -103,6 +130,9 @@ PivotCell <- R6::R6Class("PivotCell",
        rowColFilters=fstr1,
        rowFilters=fstr2,
        columnFilters=fstr3,
+       calculationFilters=fstr4,
+       workingData=wdlst,
+       evaluationFilters=fstr5,
        rowLeafCaption=private$p_rowLeafGroup$caption,
        columnLeafCaption=private$p_columnLeafGroup$caption,
        formattedValue=self$formattedValue
@@ -122,18 +152,42 @@ PivotCell <- R6::R6Class("PivotCell",
    calculationFilters = function(value) {
      if(missing(value)) { return(invisible(private$p_calculationFilters)) }
      else {
-       checkArgument("PivotCell", "calculationFilters", value, missing(value), allowMissing=FALSE, allowNull=TRUE, allowedClasses="PivotFilters")
+       if(private$p_parentPivot$argumentCheckMode > 0) {
+         checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotCell", "calculationFilters", value, missing(value), allowMissing=FALSE, allowNull=TRUE, allowedClasses="PivotFilters")
+       }
        private$p_calculationFilters <- value
        return(invisible())
      }
    },
+   workingData = function(value) {
+     if(missing(value)) { return(invisible(private$p_workingData)) }
+     else {
+       if(private$p_parentPivot$argumentCheckMode > 0) {
+         checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotCell", "workingData", value, missing(value), allowMissing=FALSE, allowNull=FALSE, allowedClasses="list")
+       }
+       private$p_workingData <- value
+       return(invisible())
+     }
+   },
+   evaluationFilters = function(value) {
+     if(missing(value)) { return(invisible(private$p_evaluationFilters)) }
+     else {
+       if(private$p_parentPivot$argumentCheckMode > 0) {
+         checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotCell", "evaluationFilters", value, missing(value), allowMissing=FALSE, allowNull=TRUE, allowedClasses="PivotFilters")
+       }
+       private$p_evaluationFilters <- value
+       return(invisible())
+     }
+   },
    rowLeafGroup = function(value) { return(invisible(private$p_rowLeafGroup)) },
    columnLeafGroup = function(value) { return(invisible(private$p_columnLeafGroup)) },
    isTotal = function(Value) { return(invisible(private$p_rowLeafGroup$isTotal|private$p_columnLeafGroup$isTotal)) },
    rawValue = function(value) {
      if(missing(value)) return(invisible(private$p_rawValue))
      else {
-       checkArgument("PivotCell", "rawValue", value, missing(value), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("integer", "numeric"))
+       if(private$p_parentPivot$argumentCheckMode > 0) {
+         checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotCell", "rawValue", value, missing(value), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("integer", "numeric"))
+       }
        private$p_rawValue <- value
        return(invisible())
      }
@@ -141,7 +195,9 @@ PivotCell <- R6::R6Class("PivotCell",
    formattedValue = function(value) {
      if(missing(value)) return(invisible(private$p_formattedValue))
      else {
-       checkArgument("PivotCell", "formattedValue", value, missing(value), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("integer", "numeric", "character"))
+       if(private$p_parentPivot$argumentCheckMode > 0) {
+         checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotCell", "formattedValue", value, missing(value), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("integer", "numeric", "character"))
+       }
        private$p_formattedValue <- value
        return(invisible())
      }
@@ -149,7 +205,9 @@ PivotCell <- R6::R6Class("PivotCell",
    baseStyleName = function(value) {
      if(missing(value)) { return(invisible(private$p_baseStyleName)) }
      else {
-       checkArgument("PivotCell", "baseStyleName", value, missing(value), allowMissing=FALSE, allowNull=FALSE, allowedClasses="character")
+       if(private$p_parentPivot$argumentCheckMode > 0) {
+         checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotCell", "baseStyleName", value, missing(value), allowMissing=FALSE, allowNull=FALSE, allowedClasses="character")
+       }
        private$p_baseStyleName <- value
        return(invisible())
      }
@@ -157,7 +215,9 @@ PivotCell <- R6::R6Class("PivotCell",
    style = function(value) {
      if(missing(value)) { return(invisible(private$p_style)) }
      else {
-       checkArgument("PivotCell", "style", value, missing(value), allowMissing=FALSE, allowNull=FALSE, allowedClasses="PivotStyle")
+       if(private$p_parentPivot$argumentCheckMode > 0) {
+         checkArgument(private$p_parentPivot$argumentCheckMode, FALSE, "PivotCell", "style", value, missing(value), allowMissing=FALSE, allowNull=FALSE, allowedClasses="PivotStyle")
+       }
        private$p_style <- value
        return(invisible())
      }
@@ -172,7 +232,9 @@ PivotCell <- R6::R6Class("PivotCell",
     p_rowFilters = NULL,              # an object ref (shared across this row)
     p_columnFilters = NULL,           # an object ref (shared across this column)
     p_rowColFilters = NULL,           # an object ref (unique to this cell)
-    p_calculationFilters = NULL,      # an object ref (unique to this cell)
+    p_calculationFilters = NULL,      # an object ref (shared across this calculation)
+    p_workingData = NULL,             # a list:  element = calculationName, value = a list of two elements (workingFilters & batchName) for the calculation
+    p_evaluationFilters = NULL,       # an obejct ref (unique to this cell)
     p_rowLeafGroup = NULL,            # an object ref (shared across this row)
     p_columnLeafGroup = NULL,         # an object ref (shared across this column)
     p_rawValue = NULL ,               # a value (unique to this cell)
